jQuery('#datetimepicker1').datetimepicker({
    format: "Y-m-d H:i:s",
    lang: 'en',
    formatDate:'d.m.Y',
    minDate: '01.08.2017',
    maxDate: 0,
    step: 5
});// JavaScript Document
jQuery('#datetimepicker2').datetimepicker({
    format: 'Y-m-d H:i:s',
    lang: 'en',
    minDate: '2014/05/01',
    maxDate: 0,
    step: 5
});